# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.applications.fee.v1 import fee_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_fee__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ibc/applications/fee/v1/genesis.proto\x12\x17ibc.applications.fee.v1\x1a\x14gogoproto/gogo.proto\x1a!ibc/applications/fee/v1/fee.proto\x1a!ibc/core/channel/v1/channel.proto\"\xc5\x04\n\x0cGenesisState\x12\x66\n\x0fidentified_fees\x18\x01 \x03(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFeesB\x1e\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:\"identified_fees\"\x12m\n\x14\x66\x65\x65_enabled_channels\x18\x02 \x03(\x0b\x32*.ibc.applications.fee.v1.FeeEnabledChannelB#\xc8\xde\x1f\x00\xf2\xde\x1f\x1byaml:\"fee_enabled_channels\"\x12\x65\n\x11registered_payees\x18\x03 \x03(\x0b\x32(.ibc.applications.fee.v1.RegisteredPayeeB \xc8\xde\x1f\x00\xf2\xde\x1f\x18yaml:\"registered_payees\"\x12\x8b\x01\n\x1eregistered_counterparty_payees\x18\x04 \x03(\x0b\x32\x34.ibc.applications.fee.v1.RegisteredCounterpartyPayeeB-\xc8\xde\x1f\x00\xf2\xde\x1f%yaml:\"registered_counterparty_payees\"\x12i\n\x10\x66orward_relayers\x18\x05 \x03(\x0b\x32..ibc.applications.fee.v1.ForwardRelayerAddressB\x1f\xc8\xde\x1f\x00\xf2\xde\x1f\x17yaml:\"forward_relayers\"\"c\n\x11\x46\x65\x65\x45nabledChannel\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\"\\\n\x0fRegisteredPayee\x12)\n\nchannel_id\x18\x01 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x0f\n\x07relayer\x18\x02 \x01(\t\x12\r\n\x05payee\x18\x03 \x01(\t\"\x94\x01\n\x1bRegisteredCounterpartyPayee\x12)\n\nchannel_id\x18\x01 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x0f\n\x07relayer\x18\x02 \x01(\t\x12\x39\n\x12\x63ounterparty_payee\x18\x03 \x01(\tB\x1d\xf2\xde\x1f\x19yaml:\"counterparty_payee\"\"t\n\x15\x46orwardRelayerAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12J\n\tpacket_id\x18\x02 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x18\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"packet_id\"B7Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _GENESISSTATE.fields_by_name['identified_fees']._options = None
  _GENESISSTATE.fields_by_name['identified_fees']._serialized_options = b'\310\336\037\000\362\336\037\026yaml:\"identified_fees\"'
  _GENESISSTATE.fields_by_name['fee_enabled_channels']._options = None
  _GENESISSTATE.fields_by_name['fee_enabled_channels']._serialized_options = b'\310\336\037\000\362\336\037\033yaml:\"fee_enabled_channels\"'
  _GENESISSTATE.fields_by_name['registered_payees']._options = None
  _GENESISSTATE.fields_by_name['registered_payees']._serialized_options = b'\310\336\037\000\362\336\037\030yaml:\"registered_payees\"'
  _GENESISSTATE.fields_by_name['registered_counterparty_payees']._options = None
  _GENESISSTATE.fields_by_name['registered_counterparty_payees']._serialized_options = b'\310\336\037\000\362\336\037%yaml:\"registered_counterparty_payees\"'
  _GENESISSTATE.fields_by_name['forward_relayers']._options = None
  _GENESISSTATE.fields_by_name['forward_relayers']._serialized_options = b'\310\336\037\000\362\336\037\027yaml:\"forward_relayers\"'
  _FEEENABLEDCHANNEL.fields_by_name['port_id']._options = None
  _FEEENABLEDCHANNEL.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _FEEENABLEDCHANNEL.fields_by_name['channel_id']._options = None
  _FEEENABLEDCHANNEL.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _REGISTEREDPAYEE.fields_by_name['channel_id']._options = None
  _REGISTEREDPAYEE.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _REGISTEREDCOUNTERPARTYPAYEE.fields_by_name['channel_id']._options = None
  _REGISTEREDCOUNTERPARTYPAYEE.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _REGISTEREDCOUNTERPARTYPAYEE.fields_by_name['counterparty_payee']._options = None
  _REGISTEREDCOUNTERPARTYPAYEE.fields_by_name['counterparty_payee']._serialized_options = b'\362\336\037\031yaml:\"counterparty_payee\"'
  _FORWARDRELAYERADDRESS.fields_by_name['packet_id']._options = None
  _FORWARDRELAYERADDRESS.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000\362\336\037\020yaml:\"packet_id\"'
  _globals['_GENESISSTATE']._serialized_start=159
  _globals['_GENESISSTATE']._serialized_end=740
  _globals['_FEEENABLEDCHANNEL']._serialized_start=742
  _globals['_FEEENABLEDCHANNEL']._serialized_end=841
  _globals['_REGISTEREDPAYEE']._serialized_start=843
  _globals['_REGISTEREDPAYEE']._serialized_end=935
  _globals['_REGISTEREDCOUNTERPARTYPAYEE']._serialized_start=938
  _globals['_REGISTEREDCOUNTERPARTYPAYEE']._serialized_end=1086
  _globals['_FORWARDRELAYERADDRESS']._serialized_start=1088
  _globals['_FORWARDRELAYERADDRESS']._serialized_end=1204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/store/v1beta1/listening.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)cosmos/base/store/v1beta1/listening.proto\x12\x19\x63osmos.base.store.v1beta1\x1a\x1btendermint/abci/types.proto\"L\n\x0bStoreKVPair\x12\x11\n\tstore_key\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\x08\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x12\r\n\x05value\x18\x04 \x01(\x0c\"\x89\x04\n\rBlockMetadata\x12?\n\x13request_begin_block\x18\x01 \x01(\x0b\x32\".tendermint.abci.RequestBeginBlock\x12\x41\n\x14response_begin_block\x18\x02 \x01(\x0b\x32#.tendermint.abci.ResponseBeginBlock\x12G\n\x0b\x64\x65liver_txs\x18\x03 \x03(\x0b\x32\x32.cosmos.base.store.v1beta1.BlockMetadata.DeliverTx\x12;\n\x11request_end_block\x18\x04 \x01(\x0b\x32 .tendermint.abci.RequestEndBlock\x12=\n\x12response_end_block\x18\x05 \x01(\x0b\x32!.tendermint.abci.ResponseEndBlock\x12\x38\n\x0fresponse_commit\x18\x06 \x01(\x0b\x32\x1f.tendermint.abci.ResponseCommit\x1au\n\tDeliverTx\x12\x32\n\x07request\x18\x01 \x01(\x0b\x32!.tendermint.abci.RequestDeliverTx\x12\x34\n\x08response\x18\x02 \x01(\x0b\x32\".tendermint.abci.ResponseDeliverTxB*Z(github.com/cosmos/cosmos-sdk/store/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.store.v1beta1.listening_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/store/types'
  _globals['_STOREKVPAIR']._serialized_start=101
  _globals['_STOREKVPAIR']._serialized_end=177
  _globals['_BLOCKMETADATA']._serialized_start=180
  _globals['_BLOCKMETADATA']._serialized_end=701
  _globals['_BLOCKMETADATA_DELIVERTX']._serialized_start=584
  _globals['_BLOCKMETADATA_DELIVERTX']._serialized_end=701
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/proposal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/peggy/v1/proposal.proto\x12\x12injective.peggy.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"\x8d\x01\n\"BlacklistEthereumAddressesProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1b\n\x13\x62lacklist_addresses\x18\x03 \x03(\t:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x8a\x01\n\x1fRevokeEthereumBlacklistProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1b\n\x13\x62lacklist_addresses\x18\x03 \x03(\t:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.ContentBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.proposal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _BLACKLISTETHEREUMADDRESSESPROPOSAL._options = None
  _BLACKLISTETHEREUMADDRESSESPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _REVOKEETHEREUMBLACKLISTPROPOSAL._options = None
  _REVOKEETHEREUMBLACKLISTPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_BLACKLISTETHEREUMADDRESSESPROPOSAL']._serialized_start=107
  _globals['_BLACKLISTETHEREUMADDRESSESPROPOSAL']._serialized_end=248
  _globals['_REVOKEETHEREUMBLACKLISTPROPOSAL']._serialized_start=251
  _globals['_REVOKEETHEREUMBLACKLISTPROPOSAL']._serialized_end=389
# @@protoc_insertion_point(module_scope)
